# SPDX-FileCopyrightText: 2025 cswimr <copyright@csw.im>
# SPDX-License-Identifier: MPL-2.0

from .tables import TABLES, AbstractPartial, Change, Moderation, PartialChannel, PartialGuild, PartialRole, PartialTargetable, PartialUser

__all__ = [
    "AbstractPartial",
    "Change",
    "Moderation",
    "PartialChannel",
    "PartialRole",
    "PartialGuild",
    "PartialUser",
    "PartialTargetable",
    "PartialGuild",
    "PartialRole",
    "TABLES",
]
